@@ -1,7 +1,7 @@
 import functools
 from collections import defaultdict
 from contextlib import suppress
-
+from twisted.internet import threads
 from scrapy.exceptions import IgnoreRequest, NotConfigured
 from scrapy.utils.datatypes import SequenceExclude
 from scrapy.utils.defer import defer_result, mustbe_deferred
@@ -235,12 +235,14 @@ class AliOssStore(object):
         self.file_upload = OssFileUpload(self.OSS_ACCESS_KEY_ID, self.OSS_SECRET_ACCESS_KEY, self.OSS_ENDPOINT_URL, self.OSS_BUCKET_NAME)
 
     def stat_file(self, path, info):
+        def _onsuccess(obj):
+            return obj
+        return threads.deferToThread(self.file_upload.exist, path).addCallback(_onsuccess)
         # always return the empty result ,force the media request to download the file
-        return self.file_upload.exist(path)
 
     def persist_file(self, path, buf, info, meta=None, headers=None):
         """Upload file to Ali oss storage"""
-        self._upload_file(path, buf)
+        return threads.deferToThread(self._upload_file, path, buf)
 
     def _upload_file(self, path, buf):
         self.file_upload.upload_object(path, buf)
